@@ -103,20 +103,36 @@ def test_swap_shushi_1_polygon():
     assert(float(swaps[0]['timestamp']) > 0)
 
 
-# def test_swap_uniswap_3_eth():
-#     uniswap = Dex(protocol="Uniswap", chain="Ethereum", version=3)
-#     swaps = uniswap.get_data_from_date_range(
-#         '15/05/2021 00:00:00', '15/05/2021 00:10:00', "swap")
-#     assert(swaps[0]['tx_id'] != "")
-#     assert(swaps[0]['protocol'] == "Uniswap")
-#     assert(swaps[0]['chain'] == "Ethereum")
-#     assert(swaps[0]['version'] == 3)
-#     assert(swaps[0]['user'] != "")
-#     assert(swaps[0]['from_token'] != "")
-#     assert(swaps[0]['to_token'] != "")
-#     assert(float(swaps[0]['from_token_amount']) > 0)
-#     assert(float(swaps[0]['to_token_amount']) > 0)
-#     assert(float(swaps[0]['timestamp']) > 0)
+def test_swap_shushi_1_fantom():
+    shushi = Dex(protocol="SushiSwap", chain="fantom", version=1)
+    swaps = shushi.get_data_from_date_range(
+        '31/08/2021 00:00:00', '31/08/2021 04:00:00', "swap")
+    assert(swaps[0]['tx_id'] != "")
+    assert(swaps[0]['protocol'] == "SushiSwap")
+    assert(swaps[0]['chain'] == "fantom")
+    assert(swaps[0]['version'] == 1)
+    assert(swaps[0]['user'] != "")
+    assert(swaps[0]['from_token'] != "")
+    assert(swaps[0]['to_token'] != "")
+    assert(float(swaps[0]['from_token_amount']) > 0)
+    assert(float(swaps[0]['to_token_amount']) > 0)
+    assert(float(swaps[0]['timestamp']) > 0)
+
+
+def test_swap_uniswap_3_eth():
+    uniswap = Dex(protocol="Uniswap", chain="Ethereum", version=3)
+    swaps = uniswap.get_data_from_date_range(
+        '31/08/2021 00:00:00', '31/08/2021 00:10:00', "swap")
+    assert(swaps[0]['tx_id'] != "")
+    assert(swaps[0]['protocol'] == "Uniswap")
+    assert(swaps[0]['chain'] == "Ethereum")
+    assert(swaps[0]['version'] == 3)
+    assert(swaps[0]['user'] != "")
+    assert(swaps[0]['from_token'] != "")
+    assert(swaps[0]['to_token'] != "")
+    assert(float(swaps[0]['from_token_amount']) > 0)
+    assert(float(swaps[0]['to_token_amount']) > 0)
+    assert(float(swaps[0]['timestamp']) > 0)
 
 
 def test_swap_ubeswap_1_celo():
@@ -134,3 +150,73 @@ def test_swap_ubeswap_1_celo():
     assert(float(swaps[0]['from_token_amount']) > 0)
     assert(float(swaps[0]['to_token_amount']) > 0)
     assert(float(swaps[0]['timestamp']) > 0)
+
+
+def test_swap_balancer_2_eth():
+    balancer = Dex(protocol="balancer", chain="ethereum", version=2)
+    swaps = balancer.get_data_from_date_range(
+        '31/08/2021 00:00:00', '31/08/2021 01:00:00', "swap")
+
+    assert(swaps[0]['tx_id'] != "")
+    assert(swaps[0]['protocol'] == "balancer")
+    assert(swaps[0]['chain'] == "ethereum")
+    assert(swaps[0]['version'] == 2)
+    assert(swaps[0]['user'] != "")
+    assert(swaps[0]['from_token'] != "")
+    assert(swaps[0]['to_token'] != "")
+    assert(float(swaps[0]['from_token_amount']) > 0)
+    assert(float(swaps[0]['to_token_amount']) > 0)
+    assert(float(swaps[0]['timestamp']) > 0)
+
+
+def test_swap_balancer_2_polygon():
+    balancer = Dex(protocol="balancer", chain="polygon", version=2)
+    swaps = balancer.get_data_from_date_range(
+        '31/08/2021 00:00:00', '31/08/2021 01:00:00', "swap")
+
+    assert(swaps[0]['tx_id'] != "")
+    assert(swaps[0]['protocol'] == "balancer")
+    assert(swaps[0]['chain'] == "polygon")
+    assert(swaps[0]['version'] == 2)
+    assert(swaps[0]['user'] != "")
+    assert(swaps[0]['from_token'] != "")
+    assert(swaps[0]['to_token'] != "")
+    assert(float(swaps[0]['from_token_amount']) > 0)
+    assert(float(swaps[0]['to_token_amount']) > 0)
+    assert(float(swaps[0]['timestamp']) > 0)
+
+
+def test_swap_balancer_2_arbitrum():
+    balancer = Dex(protocol="balancer", chain="arbitrum", version=2)
+    swaps = balancer.get_data_from_date_range(
+        '31/08/2021 00:00:00', '01/09/2021 0:01:30', "swap")
+
+    assert(swaps[0]['tx_id'] != "")
+    assert(swaps[0]['protocol'] == "balancer")
+    assert(swaps[0]['chain'] == "arbitrum")
+    assert(swaps[0]['version'] == 2)
+    assert(swaps[0]['user'] != "")
+    assert(swaps[0]['from_token'] != "")
+    assert(swaps[0]['to_token'] != "")
+    assert(float(swaps[0]['from_token_amount']) > 0)
+    assert(float(swaps[0]['to_token_amount']) > 0)
+    assert(float(swaps[0]['timestamp']) > 0)
+
+
+def test_swap_pancakeswap_2_bsc():
+    pancakeswap = Dex(protocol="pancakeswap", chain="bsc", version=2)
+    swaps = pancakeswap.get_data_from_date_range(
+        '31/08/2021 00:00:00', '01/09/2021 0:01:30', "swap")
+
+    assert(swaps[0]['tx_id'] != "")
+    assert(swaps[0]['protocol'] == "pancakeswap")
+    assert(swaps[0]['chain'] == "bsc")
+    assert(swaps[0]['version'] == 2)
+    assert(swaps[0]['user'] != "")
+    assert(swaps[0]['from_token'] != "")
+    assert(swaps[0]['to_token'] != "")
+    assert(float(swaps[0]['from_token_amount']) > 0)
+    assert(float(swaps[0]['to_token_amount']) > 0)
+    assert(float(swaps[0]['timestamp']) > 0)
+
+
